@@ -1,7 +1,6 @@
 #!/bin/bash
 
 if [ "$(uname)" == "Darwin" ]; then
-    # for Mac OSX
     export CC=clang
     export CXX=clang++
     export MACOSX_VERSION_MIN="10.9"
@@ -15,9 +14,4 @@ if [ "$(uname)" == "Darwin" ]; then
     export LINKFLAGS="${LDFLAGS}"
 fi
 
-if [[ $(uname) == "Linux" && ${ARCH} == 32 && ${PY_VER} == 3.6 ]]; then
-  # See https://bitbucket.org/rpy2/rpy2/issues/389/failed-to-compile-with-python-360-on-32
-  CFLAGS="-I${PREFIX}/include ${CFLAGS} -DHAVE_UINTPTR_T=1" "${PYTHON}" setup.py install --single-version-externally-managed --record=record.txt
-else
-  CFLAGS="-I${PREFIX}/include ${CFLAGS}" "${PYTHON}" setup.py install --single-version-externally-managed --record=record.txt
-fi
+CFLAGS="-I${PREFIX}/include ${CFLAGS}" "${PYTHON}" -m pip install --no-deps --ignore-installed .
\ No newline at end of file
